;; Generated package description from counsel.el  -*- no-byte-compile: t -*-
(define-package "counsel" "0.13.4.0.20230327.142720" "Various completion functions using Ivy" '((emacs "24.5") (ivy "0.13.4") (swiper "0.13.4")) :commit "cd47f5212a28b35d777085d95bd0cf4cf2eaadfa" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Oleh Krehel" . "ohwoeowho@gmail.com") :keywords '("convenience" "matching" "tools") :url "https://github.com/abo-abo/swiper")
